# CHANGELOG

<!-- version list -->

## v1.3.1 (2026-02-08)

### Bug Fixes

- **ci**: Publish only when semantic-release creates a release
  ([`881a513`](https://github.com/bhoshaga/struai/commit/881a513405775e73b65ae0d569085c4cc83b0534))

### Documentation

- **sdk**: Add complete method refs and real workflow examples
  ([`c8f00b1`](https://github.com/bhoshaga/struai/commit/c8f00b1f5b120f0b1319d8fc93bdff9d508cc5fb))


## v1.3.0 (2026-02-08)

### Features

- **sdk**: Rebuild Python/JS SDK contracts for full projects API surface
- **sdk**: Add multi-job sheet ingest support (`page` selectors + batch wait helpers)
- **sdk**: Add sheet annotations endpoint support

### Documentation

- **docs**: Refresh README/examples for current drawings + projects APIs

## v1.2.1 (2026-02-04)

### Documentation

- **docs**: Add full page-12 cookbook example

### Bug Fixes

- **sdk**: Allow nullable sheet fields in list responses

## v1.2.0 (2026-02-04)

### Features

- **sdk**: Cache reuse for tier2 sheets
  ([`2e43eb1`](https://github.com/bhoshaga/struai/commit/2e43eb146e76d1cf8982caa894f66ab3c7b20733))


## v1.1.1 (2026-02-04)

### Bug Fixes

- **sdk**: Send form data without files
  ([`a2132e8`](https://github.com/bhoshaga/struai/commit/a2132e8b8923d24973f33351b785db1b7d3bb7f7))


## v1.1.0 (2026-02-04)

### Features

- **sdk**: Auto cache check for drawings
  ([`2a6c006`](https://github.com/bhoshaga/struai/commit/2a6c0062dcd4bc5efba94f472de5441d30ed5300))


## v1.0.4 (2026-02-04)

### Bug Fixes

- **ci**: Checkout release tag for publish jobs
  ([`6b78004`](https://github.com/bhoshaga/struai/commit/6b78004629cee3dff309836f7879da417dd69ac9))


## v1.0.3 (2026-02-04)

### Bug Fixes

- Trigger release v1.0.3
  ([`a611906`](https://github.com/bhoshaga/struai/commit/a611906590f693d9222b2b95aa2c42830e92c156))

### Documentation

- Clarify auth and endpoints
  ([`9703efe`](https://github.com/bhoshaga/struai/commit/9703efe1354168cb32d3ed6eacea642e22bea593))


## v1.0.2 (2026-02-04)

### Bug Fixes

- **ci**: Add publish_only option for re-publishing
  ([`0806b1e`](https://github.com/bhoshaga/struai/commit/0806b1eb6dba6d518df9f43a199b9255d1776d6a))

- **ci**: Consolidate to single release workflow
  ([`91e94b0`](https://github.com/bhoshaga/struai/commit/91e94b00f5eb6e123adb2cfae01a473ed4cd5cbd))


## v1.0.1 (2026-02-04)

### Bug Fixes

- **ci**: Include publish jobs directly in release workflow
  ([`02436eb`](https://github.com/bhoshaga/struai/commit/02436eb55c63cbaa54eac8ca456a54d30125fada))


## v1.0.0 (2026-02-04)

- Initial Release
